// -*- C++ -*-
/*!
 * @file  VelConv.cpp
 * @brief Velocity Convert
 * @date $Date$
 *
 * $Id$
 */

#include "VelConv.h"

// Module specification
// <rtc-template block="module_spec">
static const char* velconv_spec[] =
  {
    "implementation_id", "VelConv",
    "type_name",         "VelConv",
    "description",       "Velocity Convert",
    "version",           "1.0.0",
    "vendor",            "Aizu",
    "category",          "Converter",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
VelConv::VelConv(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_Vel_inIn("vel_in", m_Vel_in),
    m_Vel_outOut("vel_out", m_Vel_out)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
VelConv::~VelConv()
{
}



RTC::ReturnCode_t VelConv::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("vel_in", m_Vel_inIn);
  
  // Set OutPort buffer
  addOutPort("vel_out", m_Vel_outOut);
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // </rtc-template>
  
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t VelConv::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VelConv::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VelConv::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VelConv::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t VelConv::onDeactivated(RTC::UniqueId ec_id)
{
	// o͑xxNgNA
	m_Vel_out.data.vx = 0;
	m_Vel_out.data.vy = 0;
	m_Vel_out.data.va = 0;

	// o͑xxNg
	m_Vel_outOut.write();
  return RTC::RTC_OK;
}


RTC::ReturnCode_t VelConv::onExecute(RTC::UniqueId ec_id)
{
	// ͑xxNgύXꂽꍇ
	if (m_Vel_inIn.isNew())
	{
		// ͑xxNgǍ
		m_Vel_inIn.read();

		// ͑xxNgϊAo͑xxNgɐݒ
		m_Vel_out.data.vx = m_Vel_in.data.vx * 1000;
		m_Vel_out.data.vy = 0;
		m_Vel_out.data.va = m_Vel_in.data.va * 0.23 * 1000 / 0.1185;

		printf("In[vx:%f,va:%f] Out[vx:%f,va:%f]\n", m_Vel_in.data.vx, m_Vel_in.data.va, m_Vel_out.data.vx, m_Vel_out.data.va);

		// o͑xxNg
		m_Vel_outOut.write();
	}
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t VelConv::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VelConv::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VelConv::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VelConv::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VelConv::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void VelConvInit(RTC::Manager* manager)
  {
    coil::Properties profile(velconv_spec);
    manager->registerFactory(profile,
                             RTC::Create<VelConv>,
                             RTC::Delete<VelConv>);
  }
  
};


